# Description

<!-- What has been changed? Why? -->

## Type of change

* [ ] Bug-fix
* [ ] New feature
* [ ] Breaking change
* [ ] Documentation update

## References

<!-- Are there related issues? Use e.g. write "closes #1" if this PR closes an issue. -->

## Tests

* [ ] I adapted existing tests, because
* [ ] I added new tests to cover the code change
* [ ] All tests pass with my change

## Documentation
* [ ] I rebuilt the documentation page to ensure building the pages works
* [ ] I used PEP-8 conformal code styling

## Final checks

* [ ] My change is the minimal possible work for the desired feature/fix
* [ ] I updated the documentation where necessary to cover the change
